@@ -5,7 +5,7 @@ pub fn read_input() -> String {
     let mut input = String::new();
     std::io::stdin().read_line(&mut input).unwrap();
 
-    input
+    String::from(input.trim())
 }
 
 pub enum ExitCode {
